# ozi-core CHANGELOG

{%- if context.history.unreleased | length > 0 %}

{#- UNRELEASED -#}
## Unreleased
{% for type_, commits in context.history.unreleased | dictsort %}
{% include '.parsed_commit_heading.j2' %}
{% for commit in commits %}{% if type_ != "unknown" %}
{%- filter replace(':art:', '🎨') %}
{%- filter replace(':zap:', '⚡️') %}
{%- filter replace(':fire:', '🔥') %}
{%- filter replace(':bug:', '🐛') %}
{%- filter replace(':ambulance:', '🚑️') %}
{%- filter replace(':sparkles:', '✨') %}
{%- filter replace(':memo:', '📝') %}
{%- filter replace(':rocket:', '🚀') %}
{%- filter replace(':tada:', '🎉') %}
{%- filter replace(':white_check_mark:', '✅') %}
{%- filter replace(':lock:', '🔒️') %}
{%- filter replace(':closed_lock_with_key:', '🔐') %}
{%- filter replace(':bookmark:', '🔖') %}
{%- filter replace(':rotating_light:', '🚨') %}
{%- filter replace(':construction:', '🚧') %}
{%- filter replace(':green_heart:', '💚') %}
{%- filter replace(':arrow_down:', '⬇️') %}
{%- filter replace(':arrow_up:', '⬆️') %}
{%- filter replace(':pushpin:', '📌') %}
{%- filter replace(':construction_worker:', '👷') %}
{%- filter replace(':chart_with_upwards_trend:', '📈') %}
{%- filter replace(':recycle:', '♻️') %}
{%- filter replace(':heavy_plus_sign:', '➕') %}
{%- filter replace(':heavy_minus_sign:', '➖') %}
{%- filter replace(':wrench:', '🔧') %}
{%- filter replace(':hammer:', '🔨') %}
{%- filter replace(':globe_with_meridians:', '🌐') %}
{%- filter replace(':pencil2:', '✏️') %}
{%- filter replace(':poop:', '💩') %}
{%- filter replace(':rewind:', '⏪️') %}
{%- filter replace(':twisted_rightwards_arrows:', '🔀') %}
{%- filter replace(':package:', '📦️') %}
{%- filter replace(':alien:', '👽️') %}
{%- filter replace(':truck:', '🚚') %}
{%- filter replace(':page_facing_up:', '📄') %}
{%- filter replace(':boom:', '💥') %}
{%- filter replace(':bento:', '🍱') %}
{%- filter replace(':wheelchair:', '♿️') %}
{%- filter replace(':bulb:', '💡') %}
{%- filter replace(':beers:', '🍻') %}
{%- filter replace(':speech_balloon:', '💬') %}
{%- filter replace(':card_file_box:', '🗃️') %}
{%- filter replace(':loud_sound:', '🔊') %}
{%- filter replace(':mute:', '🔇') %}
{%- filter replace(':busts_in_silhouette:', '👥') %}
{%- filter replace(':children_crossing:', '🚸') %}
{%- filter replace(':building_construction:', '🏗️') %}
{%- filter replace(':clown_face:', '🤡') %}
{%- filter replace(':egg:', '🥚') %}
{%- filter replace(':see_no_evil:', '🙈') %}
{%- filter replace(':camera_flash:', '📸') %}
{%- filter replace(':alembic:', '⚗️') %}
{%- filter replace(':mag:', '🔍️') %}
{%- filter replace(':label:', '🏷️') %}
{%- filter replace(':seedling:', '🌱') %}
{%- filter replace(':triangular_flag_on_post:', '🚩') %}
{%- filter replace(':goal_net:', '🥅') %}
{%- filter replace(':dizzy:', '💫') %}
{%- filter replace(':wastebasket:', '🗑️') %}
{%- filter replace(':passport_control:', '🛂') %}
{%- filter replace(':adhesive_bandage:', '🩹') %}
{%- filter replace(':monocle_face:', '🧐') %}
{%- filter replace(':coffin:', '⚰️') %}
{%- filter replace(':test_tube:', '🧪') %}
{%- filter replace(':necktie:', '👔') %}
{%- filter replace(':stethoscope:', '🩺') %}
{%- filter replace(':bricks:', '🧱') %}
{%- filter replace(':technologist:', '🧑‍💻') %}
{%- filter replace(':money_with_wings:', '💸') %}
{%- filter replace(':thread:', '🧵') %}
{%- filter replace(':safety_vest:', '🦺') %}
* {{ commit.commit.message.rstrip()|replace(type_~': ','')|replace(type_,'')|replace('---', '')|replace('\n\nSigned-off-by:', ' —') }}
([`{{ commit.commit.hexsha[:7] }}`]({{ commit.commit.hexsha | commit_hash_url }}))
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{% else %}
* {{ commit.commit.message.rstrip()|replace(type_~': ','')|replace(type_,'')|replace('---', '')|replace('\n\nSigned-off-by:', ' —') }}
([`{{ commit.commit.hexsha[:7] }}`]({{ commit.commit.hexsha | commit_hash_url }}))
{% endif %}{% endfor %}{% endfor %}
{% endif -%}

{#- RELEASED -#}
{% for version, release in context.history.released.items() %}
## {{ version.as_tag() }} ({{ release.tagged_date.strftime("%Y-%m-%d") }})
{% for type_, commits in release["elements"] | dictsort %}
{% include '.parsed_commit_heading.j2' %}
{% for commit in commits %}{% if type_ != "unknown" %}
{%- filter replace(':art:', '🎨') %}
{%- filter replace(':zap:', '⚡️') %}
{%- filter replace(':fire:', '🔥') %}
{%- filter replace(':bug:', '🐛') %}
{%- filter replace(':ambulance:', '🚑️') %}
{%- filter replace(':sparkles:', '✨') %}
{%- filter replace(':memo:', '📝') %}
{%- filter replace(':rocket:', '🚀') %}
{%- filter replace(':tada:', '🎉') %}
{%- filter replace(':white_check_mark:', '✅') %}
{%- filter replace(':lock:', '🔒️') %}
{%- filter replace(':closed_lock_with_key:', '🔐') %}
{%- filter replace(':bookmark:', '🔖') %}
{%- filter replace(':rotating_light:', '🚨') %}
{%- filter replace(':construction:', '🚧') %}
{%- filter replace(':green_heart:', '💚') %}
{%- filter replace(':arrow_down:', '⬇️') %}
{%- filter replace(':arrow_up:', '⬆️') %}
{%- filter replace(':pushpin:', '📌') %}
{%- filter replace(':construction_worker:', '👷') %}
{%- filter replace(':chart_with_upwards_trend:', '📈') %}
{%- filter replace(':recycle:', '♻️') %}
{%- filter replace(':heavy_plus_sign:', '➕') %}
{%- filter replace(':heavy_minus_sign:', '➖') %}
{%- filter replace(':wrench:', '🔧') %}
{%- filter replace(':hammer:', '🔨') %}
{%- filter replace(':globe_with_meridians:', '🌐') %}
{%- filter replace(':pencil2:', '✏️') %}
{%- filter replace(':poop:', '💩') %}
{%- filter replace(':rewind:', '⏪️') %}
{%- filter replace(':twisted_rightwards_arrows:', '🔀') %}
{%- filter replace(':package:', '📦️') %}
{%- filter replace(':alien:', '👽️') %}
{%- filter replace(':truck:', '🚚') %}
{%- filter replace(':page_facing_up:', '📄') %}
{%- filter replace(':boom:', '💥') %}
{%- filter replace(':bento:', '🍱') %}
{%- filter replace(':wheelchair:', '♿️') %}
{%- filter replace(':bulb:', '💡') %}
{%- filter replace(':beers:', '🍻') %}
{%- filter replace(':speech_balloon:', '💬') %}
{%- filter replace(':card_file_box:', '🗃️') %}
{%- filter replace(':loud_sound:', '🔊') %}
{%- filter replace(':mute:', '🔇') %}
{%- filter replace(':busts_in_silhouette:', '👥') %}
{%- filter replace(':children_crossing:', '🚸') %}
{%- filter replace(':building_construction:', '🏗️') %}
{%- filter replace(':clown_face:', '🤡') %}
{%- filter replace(':egg:', '🥚') %}
{%- filter replace(':see_no_evil:', '🙈') %}
{%- filter replace(':camera_flash:', '📸') %}
{%- filter replace(':alembic:', '⚗️') %}
{%- filter replace(':mag:', '🔍️') %}
{%- filter replace(':label:', '🏷️') %}
{%- filter replace(':seedling:', '🌱') %}
{%- filter replace(':triangular_flag_on_post:', '🚩') %}
{%- filter replace(':goal_net:', '🥅') %}
{%- filter replace(':dizzy:', '💫') %}
{%- filter replace(':wastebasket:', '🗑️') %}
{%- filter replace(':passport_control:', '🛂') %}
{%- filter replace(':adhesive_bandage:', '🩹') %}
{%- filter replace(':monocle_face:', '🧐') %}
{%- filter replace(':coffin:', '⚰️') %}
{%- filter replace(':test_tube:', '🧪') %}
{%- filter replace(':necktie:', '👔') %}
{%- filter replace(':stethoscope:', '🩺') %}
{%- filter replace(':bricks:', '🧱') %}
{%- filter replace(':technologist:', '🧑‍💻') %}
{%- filter replace(':money_with_wings:', '💸') %}
{%- filter replace(':thread:', '🧵') %}
{%- filter replace(':safety_vest:', '🦺') %}
* {{ commit.commit.message.rstrip()|replace(type_~': ','')|replace(type_,'')|replace('---', '')|replace('\n\nSigned-off-by:', ' —') }}
([`{{ commit.commit.hexsha[:7] }}`]({{ commit.commit.hexsha | commit_hash_url }}))
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{%- endfilter %}
{% else %}
* {{ commit.commit.message.rstrip()|replace(type_~': ','')|replace(type_,'')|replace('---', '')|replace('\n\nSigned-off-by:', ' —') }}
([`{{ commit.commit.hexsha[:7] }}`]({{ commit.commit.hexsha | commit_hash_url }}))
{% endif %}{% endfor %}{% endfor %}{% endfor %}

## 0.0.0 (2024-07-09)

### :tada:

* :tada:: Initialized ozi-core with ``ozi-new``.

```sh
ozi-new project --name ozi-core --summary 'The OZI Project packaging core library.' --keywords OZI,mesonbuild --home-page https://www.oziproject.dev --author 'Eden Ross Duff MSc' --author-email help@oziproject.dev --license 'OSI Approved :: Apache Software License' --license-expression 'Apache-2.0 WITH LLVM-exception' --requires-dist 'pyparsing~=3.1' --requires-dist 'GitPython>=3' --requires-dist 'TAP-Producer~=0.1.1' --requires-dist 'meson[ninja]>=1.1.0' --requires-dist requests --requires-dist types-requests --requires-dist 'packaging~=24.0' --requires-dist spdx-license-list --requires-dist 'ozi-spec~=0.5' --requires-dist 'ozi-templates~=2.5.1'
```